An animation library for Reagent (ClojureScript). There is only one concept: A reaction that moves toward some target, each step triggers another update until it reaches the end state. The trigger occurs by touching a local atom a zero timeout, which changes the atom in the next Reagent render.
An animation library for Reagent (ClojureScript). There is only one concept: A reaction that moves toward some target, each step triggers another update until it reaches the end state. The trigger occurs by touching a local atom a zero timeout, which changes the atom in the next Reagent render.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |